@@ -46,13 +46,18 @@ def eventbox(visible=False, add=None, w=-1, h=-1, state=None):
 	return tmpevbox
 
 def button(text=None, stock=None, relief=None, focus=True, \
-           hidetxt=False, img=None, w=-1, h=-1):
+           hidetxt=False, img=None, w=-1, h=-1, stocksize=None):
 	tmpbut = gtk.Button()
 	if text:
 		tmpbut.set_label(text)
 	elif stock:
-		tmpbut.set_label(stock)
-		tmpbut.set_use_stock(True)
+		if stocksize is not None:
+			stockimg = gtk.image_new_from_stock(stock, stocksize)
+			tmpbut.set_image(stockimg)
+			tmpbut.set_label("")
+		else:
+			tmpbut.set_label(stock)
+			tmpbut.set_use_stock(True)
 	tmpbut.set_use_underline(True)
 	if img:
 		tmpbut.set_image(img)
